@@ -1,19 +1,15 @@
-#[macro_use]
-extern crate lazy_static;
-
 pub mod de;
-pub mod ser;
 pub mod error;
+pub mod hex;
+pub mod ser;
 pub mod set;
 pub mod symbol;
 pub mod value;
 
 #[cfg(test)]
 mod dom {
-    use super::value::{
-        Value, IOValue, IOResult, NestedValue, PlainValue, Domain,
-        PackedWriter,
-    };
+    use std::io;
+    use super::value::*;
 
     #[derive(Debug, Hash, Clone, Ord, PartialEq, Eq, PartialOrd)]
     pub enum Dom {
@@ -21,34 +17,30 @@ mod dom {
         Two,
     }
 
-    impl Domain for Dom {
-        fn from_preserves(v: IOValue) -> IOResult<Self> {
-            panic!("Cannot decode IOValue to Dom: {:?}", v);
-        }
+    impl Domain for Dom {}
 
-        fn as_preserves(&self) -> IOValue {
-            match self {
-                Dom::One => Value::ByteString(vec![255, 255, 255, 255]).wrap(),
-                Dom::Two => Value::symbol(&format!("Dom::{:?}", self)).wrap(),
-            }
-        }
+    fn dom_as_preserves(v: &Dom) -> io::Result<UnwrappedIOValue> {
+        Ok(match v {
+            Dom::One => Value::ByteString(vec![255, 255, 255, 255]),
+            Dom::Two => Value::symbol(&format!("Dom::{:?}", v)),
+        })
     }
 
     #[test] fn test_one() {
         let v: PlainValue<_> = Value::from(vec![Value::from(1).wrap(),
-                                                Value::Domain(Dom::One).wrap(),
+                                                Value::Embedded(Dom::One).wrap(),
                                                 Value::from(2).wrap()])
             .wrap();
-        assert_eq!(PackedWriter::encode(&v.to_io_value()).unwrap(),
+        assert_eq!(PackedWriter::encode_iovalue(&v.copy_via(&mut dom_as_preserves).unwrap()).unwrap(),
                    [0xb5, 0x91, 0xb2, 0x04, 255, 255, 255, 255, 0x92, 0x84]);
     }
 
     #[test] fn test_two() {
         let v: PlainValue<_> = Value::from(vec![Value::from(1).wrap(),
-                                                Value::Domain(Dom::Two).wrap(),
+                                                Value::Embedded(Dom::Two).wrap(),
                                                 Value::from(2).wrap()])
             .wrap();
-        assert_eq!(PackedWriter::encode(&v.to_io_value()).unwrap(),
+        assert_eq!(PackedWriter::encode_iovalue(&v.copy_via(&mut dom_as_preserves).unwrap()).unwrap(),
                    [0xb5, 0x91, 0xb3, 0x08, 68, 111, 109, 58, 58, 84, 119, 111, 0x92, 0x84]);
     }
 }
@@ -232,7 +224,7 @@ mod value_tests {
 
 #[cfg(test)]
 mod decoder_tests {
-    use crate::value::{Value, NestedValue, PackedReader, ConfiguredReader};
+    use crate::value::{Value, NestedValue, BinarySource, BytesBinarySource, ConfiguredReader};
     use crate::de::from_bytes;
     use crate::error::{Error, ExpectedKind, is_eof_io_error};
 
@@ -254,7 +246,8 @@ mod decoder_tests {
 
     #[test] fn skip_annotations_noskip() {
         let buf = &b"\x85\x92\x91"[..];
-        let mut d = ConfiguredReader::new(PackedReader::decode_bytes(&buf));
+        let mut src = BytesBinarySource::new(&buf);
+        let mut d = ConfiguredReader::new(src.packed_iovalues());
         let v = d.demand_next().unwrap();
         assert_eq!(v.annotations().slice().len(), 1);
         assert_eq!(v.annotations().slice()[0], Value::from(2).wrap());
@@ -263,7 +256,8 @@ mod decoder_tests {
 
     #[test] fn skip_annotations_skip() {
         let buf = &b"\x85\x92\x91"[..];
-        let mut d = ConfiguredReader::new(PackedReader::decode_bytes(&buf));
+        let mut src = BytesBinarySource::new(&buf);
+        let mut d = ConfiguredReader::new(src.packed_iovalues());
         d.set_read_annotations(false);
         let v = d.demand_next().unwrap();
         assert_eq!(v.annotations().slice().len(), 0);
@@ -273,7 +267,8 @@ mod decoder_tests {
     #[test] fn multiple_values_buf_advanced() {
         let buf = &b"\xb4\xb3\x04Ping\x84\xb4\xb3\x04Pong\x84"[..];
         assert_eq!(buf.len(), 16);
-        let mut d = ConfiguredReader::new(PackedReader::decode_bytes(&buf));
+        let mut src = BytesBinarySource::new(&buf);
+        let mut d = ConfiguredReader::new(src.packed_iovalues());
         assert_eq!(d.reader.source.index, 0);
         assert_eq!(d.demand_next().unwrap().value(), &Value::simple_record0("Ping"));
         assert_eq!(d.reader.source.index, 8);
@@ -472,7 +467,7 @@ mod serde_tests {
         println!("== y: {:#?}", &y);
         assert_eq!(v, y);
 
-        let v_bytes_1 = PackedWriter::encode(&w).unwrap();
+        let v_bytes_1 = PackedWriter::encode_iovalue(&w).unwrap();
         println!("== w bytes = {:?}", v_bytes_1);
         assert_eq!(expected_bytes, v_bytes_1);
 
