@@ -35,6 +35,10 @@ pub trait NestedValue<D: Embeddable>: Sized + Debug + Clone + Eq + Hash + Ord {
         Value::Embedded(e.into()).wrap()
     }
 
+    fn symbol(n: &str) -> Self {
+        Value::symbol(n).wrap()
+    }
+
     fn wrap(anns: Annotations<Self, D>, v: Value<Self, D>) -> Self;
 
     fn annotations(&self) -> &Annotations<Self, D>;
