@@ -1,12 +1,12 @@
 use preserves::symbol::Symbol;
 use preserves::value::{IOValue, Map};
 
-#[derive(Debug, serde::Serialize, serde::Deserialize)]
+#[derive(Debug, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
 pub struct TestCases {
     pub tests: Map<Symbol, TestCase>
 }
 
-#[derive(Debug, serde::Serialize, serde::Deserialize)]
+#[derive(Debug, PartialEq, Eq, serde::Serialize, serde::Deserialize)]
 pub enum TestCase {
     Test(#[serde(with = "serde_bytes")] Vec<u8>, IOValue),
     NondeterministicTest(#[serde(with = "serde_bytes")] Vec<u8>, IOValue),
